==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_functions/mp7396_001/MP7396_RemoveWorkOrderEquipment_001.java <==

package net.datastream.schemas.mp_functions.mp7396_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="confirmequipmentchecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Remove" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrderEquipment" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workorderid",
    "relatedworkorderid"
})
@XmlRootElement(name = "MP7396_RemoveWorkOrderEquipment_001")
public class MP7396_RemoveWorkOrderEquipment_001 {

    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOID_Type workorderid;
    @XmlElement(name = "RELATEDWORKORDERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOID_Type relatedworkorderid;
    @XmlAttribute(name = "confirmequipmentchecklist")
    protected String confirmequipmentchecklist;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété workorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Définit la valeur de la propriété workorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Obtient la valeur de la propriété relatedworkorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Définit la valeur de la propriété relatedworkorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Obtient la valeur de la propriété confirmequipmentchecklist.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmequipmentchecklist() {
        if (confirmequipmentchecklist == null) {
            return "prompt";
        } else {
            return confirmequipmentchecklist;
        }
    }

    /**
     * Définit la valeur de la propriété confirmequipmentchecklist.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmequipmentchecklist(String value) {
        this.confirmequipmentchecklist = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.REMOVE;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER_EQUIPMENT;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp7396_001/MP7396_RemoveWorkOrderEquipment_001.java <==

package net.datastream.schemas.mp_functions.mp7396_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID"/>
 *       </sequence>
 *       <attribute name="confirmequipmentchecklist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Remove" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrderEquipment" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workorderid",
    "relatedworkorderid"
})
@XmlRootElement(name = "MP7396_RemoveWorkOrderEquipment_001")
public class MP7396_RemoveWorkOrderEquipment_001 {

    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOID_Type workorderid;
    @XmlElement(name = "RELATEDWORKORDERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOID_Type relatedworkorderid;
    @XmlAttribute(name = "confirmequipmentchecklist")
    protected String confirmequipmentchecklist;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Gets the value of the relatedworkorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Sets the value of the relatedworkorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Gets the value of the confirmequipmentchecklist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmequipmentchecklist() {
        if (confirmequipmentchecklist == null) {
            return "prompt";
        } else {
            return confirmequipmentchecklist;
        }
    }

    /**
     * Sets the value of the confirmequipmentchecklist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmequipmentchecklist(String value) {
        this.confirmequipmentchecklist = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.REMOVE;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER_EQUIPMENT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
